'************************************************
' File:    ImagingScan.vbs (WSH sample in VBScript) 
' Author:  Gnter Born
'
' Demonstrates how to use the Imaging ActiveX 
' control to scan images.
' Uses Internet Explorer 4.0/5.0 as front end.
'************************************************
Option Explicit

Const title = "Born's Imaging Scanner"

Const BEST_FIT = 0	' Fits image to window size
Const FIT_TO_WIDTH = 1	' Fits image to window width
Const FIT_TO_HEIGHT = 2	' Fits image to window height
Const INCH_TO_INCH = 3	' Maintains the relative size 

' Fileformats
Const wiFileTypeTIFF = 1 ' Tag Image File Format
Const wiFileTypeAWD = 2  ' At Work Document (MS Fax)
Const wiFileTypeBMP = 3  ' Microsoft Bitmap Format
Const wiFileTypePCX = 4  ' ZSoft PCX
Const wiFileTypeDCX = 5  ' modfied ZSoft PCX for Fax
Const wiFileTypeJPG = 6  ' JPEG
Const wiFileTypeXIF = 7  ' Xerox image documents
Const wiFileTypeGIF = 8  ' Graphic Interchange Format
Const wiFileTypeWIFF = 9 ' Wang Image File Format

Const open = 0       ' Dialog values
Const saveas = 1

Const CHECK_READONLY = &H01  ' Read Only check box checked
Const HIDE_READONLY = &H04   ' Hides the Read-Only check box
Const SET_CURDIR = &H08      ' set current directory in dialog
Const HELP_BUTTON = &H10     ' Show Help button in dialog box 

' define object variable for reference to Internet Explorer
Dim oIE                 ' important, variable oIE must be global
Dim oAdmin              ' to admin object
Dim oEdit               ' to edit object
Dim oScan               ' to scan object

Dim fileout, txt, tmp
Dim ImgType, tmpflag

 tmpflag = false        ' no temporary file 
 fileout = "Picture"    ' init file name
 ImgType = Array ("unknown","Tiff", "Awd", "Bmp", _
                  "PCX", "DCX", "JPG", "XIF", _
                  "GIF", "WIFF")

' launch IE and load HTML page with control
  MakeHTMLPage "imaging.htm"

' create object references
  Set oAdmin = oIE.Document.All.admin ' Admin control
  Set oEdit = oIE.Document.All.edit  ' Edit control
  Set oScan =  oIE.Document.All.scan  ' Scan control
  
 If MsgBox ("Scan image?" _
    , vbYesNo + vbSystemModal, Title) = vbYes Then
  If Not oScan.ScannerAvailable Then
   WScript.Echo "No Scanner available"
  Else
  ' direct output 
  ' 0 display, 
  ' 1 display and write to file
  ' 2 write to file
  ' 3 write to template and display
  ' 4 write to template file
  ' 5 fax
   oScan.ScanTo 0         ' display scan
   oScan.ShowScanPreferences
   oScan.StartScan
  End if
 End If

 If MsgBox ("Save image as?" _
    , vbYesNo + vbSystemModal, Title) = vbYes Then
    
  oAdmin.Filter = "All image files|*.tif;*.bmp|" & _
                  "TIFF files|*.tif|" & _
                  "BMP files|*.bmp|" & _
                  "All files|*.*|"
  oAdmin.FilterIndex = 2          ' set tif filter
  oAdmin.InitDir = GetPath()      ' set initial directory
  oAdmin.CancelError = false      ' Cancel causes no run-time error

  oAdmin.ShowFileDialog saveas    ' Show SaveAs dialog
  fileout = oAdmin.Image          ' get selected file name
  If fileout <> "" Then
 ' Note: We can omit the file type, but when the user just
 ' specify the filename without an extension, SaveAs creates
 ' the file without the extension! If no extension is given,
 ' GetFileExt() returns .tif.
   oEdit.SaveAs fileout, GetFileType(GetFileExt(fileout))
  End if
 End If
 
 If MsgBox ("Copy image to Clipboard?" _
    , vbYesNo + vbSystemModal, Title) = vbYes Then
' Important: Before we can copy to clipboard,
' the image must be displayed, therefore we must save 
' the image to a temporary template
  oEdit.Image = GetPath() + "Temp.bmp"
  oEdit.SaveAs oEdit.Image
  oEdit.AutoRefresh = true
  oEdit.Display    
  tmpflag = true          ' set flag

' copy whole image to clipboard    
  oEdit.ClipboardCopy 0, 0, oEdit.ImageWidth, oEdit.ImageHeight
  If MsgBox ("Read Clipboard data?" _
    , vbYesNo + vbSystemModal, Title) = vbYes Then
   If oEdit.IsClipboardDataAvailable Then
    oEdit.ClipBoardPaste
    MsgBox "Image pasted", vbSystemModal, Title
   End if
  End if 
 End if

 If MsgBox ("Print image?" _
    , vbYesNo + vbSystemModal, Title) = vbYes Then
' Important: Before we can print, the image must be 
' displayed, therefore save to temporary template
  oEdit.Image = GetPath() + "Temp.bmp"
  oEdit.SaveAs oEdit.Image
  oEdit.AutoRefresh = true
  oEdit.Display    
  tmpflag = true          ' set flag  

  oEdit.PrintImage        ' print
End if

' ### some book keeping here
' Delete the temp file
 If tmpFlag Then _ 
   oAdmin.Delete GetPath() + "Temp.bmp"  

 oIE.Quit               ' close Internet Explorer
 Set oIE = Nothing      ' reset object variable 
 
 WScript.Quit           ' Ready

'### Helper ####
Sub MakeHTMLPage (file)
' Launch Internet Explorer and load a page

' *** launch Internet Explorer ***
Set oIE = WScript.CreateObject("InternetExplorer.Application")
 oIE.top = 10
 oIE.left = 10
 oIE.width = 600
 oIE.height = 520
 oIE.menubar = 0         ' no menu
 oIE.toolbar = 0
 oIE.statusbar = 0
 oIE.navigate GetPath() & file ' Form
 oIE.visible = 1         ' keep visible

' Important: wait till MSIE is ready
  Do While (oIE.Busy): Loop
End Sub

Function GetFileType (ext)
' Retrieve the file type from extension
 Select Case LCase(ext)
  Case ".tif"
   GetFileType = wiFileTypeTIFF
  Case ".tiff"
   GetFileType = wiFileTypeTIFF
  Case ".awd"
   GetFileType = wiFileTypeAWD
  Case ".bmp"
   GetFileType = wiFileTypeBMP
  Case Else    ' ### Panic - exit immediately
   MsgBox "Unknown extension " & ext, _
    vbOkOnly + vbError + vbSystemModal, Title
   oIE.Quit             ' close IE window
   WScript.Quit 1
 End Select
End Function

Function GetFileExt(fname)
Dim tmp
' Retrieve the files extension, set default to .tif
 If InstrRev(fname, ".") = 0 Then
  tmp = ".tif"              ' no extension found
 Else                       ' extract extension
  tmp = Right(fname, Len(fname) + 1 - InstrRev(fname, "."))
 End if
 GetFileExt = tmp
End Function

Function GetPath()
' Retrieve the script path
 DIM path
 path = WScript.ScriptFullName  ' Script name
 GetPath = Left(path, InstrRev(path, "\"))
End Function
' End